#  tests for pyamg-3.3.2-py37h830ac7b_0 (this is a generated file);
print('===== testing package: pyamg-3.3.2-py37h830ac7b_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import sys

print("sys.platform = ", sys.platform)
print("sys.version = ", sys.version)

import pyamg
pyamg.test(verbose=True)
#  --- run_test.py (end) ---

print('===== pyamg-3.3.2-py37h830ac7b_0 OK =====');
print("import: 'pyamg'")
import pyamg

print("import: 'pyamg.amg_core._amg_core'")
import pyamg.amg_core._amg_core

print("import: 'pyamg.aggregation'")
import pyamg.aggregation

print("import: 'pyamg.aggregation.tests'")
import pyamg.aggregation.tests

print("import: 'pyamg.amg_core'")
import pyamg.amg_core

print("import: 'pyamg.classical'")
import pyamg.classical

print("import: 'pyamg.classical.tests'")
import pyamg.classical.tests

print("import: 'pyamg.gallery'")
import pyamg.gallery

print("import: 'pyamg.gallery.tests'")
import pyamg.gallery.tests

print("import: 'pyamg.krylov'")
import pyamg.krylov

print("import: 'pyamg.krylov.tests'")
import pyamg.krylov.tests

print("import: 'pyamg.relaxation'")
import pyamg.relaxation

print("import: 'pyamg.relaxation.tests'")
import pyamg.relaxation.tests

print("import: 'pyamg.tests'")
import pyamg.tests

print("import: 'pyamg.util'")
import pyamg.util

print("import: 'pyamg.util.tests'")
import pyamg.util.tests

print("import: 'pyamg.vis'")
import pyamg.vis

print("import: 'pyamg.vis.tests'")
import pyamg.vis.tests

