
# THIS FILE IS GENERATED FROM SETUP.PY
short_version = '3.3.2'
version = '3.3.2'
full_version = '3.3.2'
git_revision = '683beda9dff76f0c5270b748431977f76686a76a'
release = True
if not release:
    version = full_version
